@@ -17,7 +17,7 @@
 #define USAGE " [-v] [-w sec] command service ..."
 #define USAGELSB " [-w sec] command"
 
-#define VERSION "$Id: sv.c,v 1.11 2006/03/04 14:14:49 pape Exp $"
+#define VERSION "$Id: sv.c,v 1.13 2006/11/02 22:59:15 pape Exp $"
 
 #define FATAL   "fatal: "
 #define FAIL    "fail: "
@@ -208,6 +208,7 @@ int check(char *a) {
   unsigned int pid;
 
   if ((r =svstatus_get()) == -1) return(-1);
+  while (*a) {
   if (r == 0) { if (*a == 'x') return(1); return(-1); }
   pid =(unsigned char)svstatus[15];
   pid <<=8; pid +=(unsigned char)svstatus[14];
@@ -215,10 +216,14 @@ int check(char *a) {
   pid <<=8; pid +=(unsigned char)svstatus[12];
   switch (*a) {
   case 'x': return(0);
-  case 'u': if (!pid) return(0); if (!checkscript()) return(0); break;
+  case 'u':
+    if (!pid || svstatus[19] != 1) return(0);
+    if (!checkscript()) return(0);
+    break;
   case 'd': if (pid) return(0); break;
-  case 'c': if (pid) if (!checkscript()) return(0); break;
+    case 'C': if (pid) if (!checkscript()) return(0); break;
   case 't':
+    case 'k':
     if (!pid && svstatus[17] == 'd') break;
     tai_unpack(svstatus, &tstatus);
     if ((tstart.sec.x > tstatus.x) || !pid || svstatus[18] || !checkscript())
@@ -228,6 +233,11 @@ int check(char *a) {
     tai_unpack(svstatus, &tstatus);
     if ((!pid && tstart.sec.x > tstatus.x) || (pid && svstatus[17] != 'd'))
       return(0);
+      break;
+    case 'p': if (pid && !svstatus[16]) return(0); break;
+    case 'c': if (pid && svstatus[16]) return(0); break;
+    }
+    ++a;
   }
   outs(OK); svstatus_print(*service); flush("\n");
   return(1);
@@ -269,7 +279,7 @@ int main(int argc, char **argv) {
     case 'w': scan_ulong(optarg, &wait);
     case 'v': verbose =1; break;
     case 'V':
-      strerr_warn1("$Id: sv.c,v 1.11 2006/03/04 14:14:49 pape Exp $", 0);
+      strerr_warn1("$Id: sv.c,v 1.13 2006/11/02 22:59:15 pape Exp $", 0);
     case '?': usage();
     }
   }
@@ -294,7 +304,7 @@ int main(int argc, char **argv) {
   case 'T':
     acts ="tc"; kll =1; cbk =&check; break;
   case 'c':
-    if (!str_diff(action, "check")) { act =0; acts ="c"; cbk =&check; break; }
+    if (!str_diff(action, "check")) { act =0; acts ="C"; cbk =&check; break; }
   case 'u': case 'd': case 'o': case 't': case 'p': case 'h':
   case 'a': case 'i': case 'k': case 'q': case '1': case '2':
     action[1] =0; acts =action; break;
