@@ -50,7 +50,7 @@ int main(int argc, const char * const *argv) {
       verbose =1;
       break;
     case 'V':
-      strerr_warn1("$Id: svwaitup.c,v 1.8 2005/01/10 19:35:51 pape Exp $", 0);
+      strerr_warn1("$Id: svwaitup.c,v 1.9 2005/04/03 09:21:47 pape Exp $", 0);
     case '?':
       usage();
     }
@@ -71,7 +71,7 @@ int main(int argc, const char * const *argv) {
     }
     if ((fd =open_write("supervise/ok")) == -1) {
       if (errno == error_nodevice)
-	warn(*dir, ": supervise not running.", 0);
+	warn(*dir, ": runsv not running.", 0);
       else
 	warn(*dir, ": unable to open supervise/ok: ", &strerr_sys);
       continue;
